@@ -60,9 +60,12 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
 
         csv_path = csv_path_list[0]
         try:
-            df_day = pd.read_csv(csv_path[0])
+            df_day = pd.read_csv(csv_path)
         except pd.errors.EmptyDataError:
-            raise Exception("pandas.errors.EmptyDataError (screen_status) : " + csv_path[0])
+            raise Exception("pandas.errors.EmptyDataError (screen_status) : " + csv_path)
+        except pd.errors.ParseError:
+            raise Exception("pandas.errors.ParseError (screen_status) : " + csv_path)
+
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
             df_logs_combined = pd.concat([df_logs_combined, df_day])
