@@ -51,7 +51,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
     if len(validated_date_list) == 0:
         print("Cannot find logs file around {}".format(date_in_study))
-        return None
+        return df_logs_combined
 
     for date in validated_date_list:
         date_folder_path = intermediate_participant_path + sep + date
@@ -120,8 +120,13 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
     # Read, parse and combine related intermediate file
     df_logs_combined = combine_intermediate_file(intermediate_participant_path, date_in_study)
 
-    # Match the combined parsed intermediate file with prompt feature data frame
-    waking_hours_column, sleep_hours_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+    if df_logs_combined.shape[0] > 0:
+        # Match the combined parsed intermediate file with prompt feature data frame
+        waking_hours_column, sleep_hours_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+    else:
+        waking_hours_column = ["NF"] * len(prompt_local_datetime_series)
+
     print("     --- success")
 
+
     return waking_hours_column, sleep_hours_column
