@@ -47,11 +47,6 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
 
 
     # - Outcome variable: completion status
-    try:
-        l = df_prompt['Answer_Status']
-    except KeyError:
-        raise Exception("KeyError : " + df_prompt)
-
     completion_status_binary = feature_engineering_ema.compliance.create_column(df_prompt['Answer_Status'],
                                                                                     print_stats)
     # - Feature matrix
